<?php

namespace B2buy\Ytrrr\Http\Controllers;

use App\Http\Controllers\ResourceController as BaseController;
use Form;
use B2buy\Ytrrr\Http\Requests\OrdetrRequest;
use B2buy\Ytrrr\Interfaces\OrdetrRepositoryInterface;
use B2buy\Ytrrr\Models\Ordetr;

/**
 * Resource controller class for ordetr.
 */
class OrdetrResourceController extends BaseController
{

    /**
     * Initialize ordetr resource controller.
     *
     * @param type OrdetrRepositoryInterface $ordetr
     *
     * @return null
     */
    public function __construct(OrdetrRepositoryInterface $ordetr)
    {
        parent::__construct();
        $this->repository = $ordetr;
        $this->repository
            ->pushCriteria(\Litepie\Repository\Criteria\RequestCriteria::class)
            ->pushCriteria(\B2buy\Ytrrr\Repositories\Criteria\OrdetrResourceCriteria::class);
    }

    /**
     * Display a list of ordetr.
     *
     * @return Response
     */
    public function index(OrdetrRequest $request)
    {
        $view = $this->response->theme->listView();

        if ($this->response->typeIs('json')) {
            $function = camel_case('get-' . $view);
            return $this->repository
                ->setPresenter(\B2buy\Ytrrr\Repositories\Presenter\OrdetrPresenter::class)
                ->$function();
        }

        $ordetrs = $this->repository->paginate();

        return $this->response->setMetaTitle(trans('ytrrr::ordetr.names'))
            ->view('ytrrr::ordetr.index', true)
            ->data(compact('ordetrs', 'view'))
            ->output();
    }

    /**
     * Display ordetr.
     *
     * @param Request $request
     * @param Model   $ordetr
     *
     * @return Response
     */
    public function show(OrdetrRequest $request, Ordetr $ordetr)
    {

        if ($ordetr->exists) {
            $view = 'ytrrr::ordetr.show';
        } else {
            $view = 'ytrrr::ordetr.new';
        }

        return $this->response->setMetaTitle(trans('app.view') . ' ' . trans('ytrrr::ordetr.name'))
            ->data(compact('ordetr'))
            ->view($view, true)
            ->output();
    }

    /**
     * Show the form for creating a new ordetr.
     *
     * @param Request $request
     *
     * @return Response
     */
    public function create(OrdetrRequest $request)
    {

        $ordetr = $this->repository->newInstance([]);
        return $this->response->setMetaTitle(trans('app.new') . ' ' . trans('ytrrr::ordetr.name')) 
            ->view('ytrrr::ordetr.create', true) 
            ->data(compact('ordetr'))
            ->output();
    }

    /**
     * Create new ordetr.
     *
     * @param Request $request
     *
     * @return Response
     */
    public function store(OrdetrRequest $request)
    {
        try {
            $attributes              = $request->all();
            $attributes['user_id']   = user_id();
            $attributes['user_type'] = user_type();
            $ordetr                 = $this->repository->create($attributes);

            return $this->response->message(trans('messages.success.created', ['Module' => trans('ytrrr::ordetr.name')]))
                ->code(204)
                ->status('success')
                ->url(guard_url('ytrrr/ordetr/' . $ordetr->getRouteKey()))
                ->redirect();
        } catch (Exception $e) {
            return $this->response->message($e->getMessage())
                ->code(400)
                ->status('error')
                ->url(guard_url('/ytrrr/ordetr'))
                ->redirect();
        }

    }

    /**
     * Show ordetr for editing.
     *
     * @param Request $request
     * @param Model   $ordetr
     *
     * @return Response
     */
    public function edit(OrdetrRequest $request, Ordetr $ordetr)
    {
        return $this->response->setMetaTitle(trans('app.edit') . ' ' . trans('ytrrr::ordetr.name'))
            ->view('ytrrr::ordetr.edit', true)
            ->data(compact('ordetr'))
            ->output();
    }

    /**
     * Update the ordetr.
     *
     * @param Request $request
     * @param Model   $ordetr
     *
     * @return Response
     */
    public function update(OrdetrRequest $request, Ordetr $ordetr)
    {
        try {
            $attributes = $request->all();

            $ordetr->update($attributes);
            return $this->response->message(trans('messages.success.updated', ['Module' => trans('ytrrr::ordetr.name')]))
                ->code(204)
                ->status('success')
                ->url(guard_url('ytrrr/ordetr/' . $ordetr->getRouteKey()))
                ->redirect();
        } catch (Exception $e) {
            return $this->response->message($e->getMessage())
                ->code(400)
                ->status('error')
                ->url(guard_url('ytrrr/ordetr/' . $ordetr->getRouteKey()))
                ->redirect();
        }

    }

    /**
     * Remove the ordetr.
     *
     * @param Model   $ordetr
     *
     * @return Response
     */
    public function destroy(OrdetrRequest $request, Ordetr $ordetr)
    {
        try {

            $ordetr->delete();
            return $this->response->message(trans('messages.success.deleted', ['Module' => trans('ytrrr::ordetr.name')]))
                ->code(202)
                ->status('success')
                ->url(guard_url('ytrrr/ordetr/0'))
                ->redirect();

        } catch (Exception $e) {

            return $this->response->message($e->getMessage())
                ->code(400)
                ->status('error')
                ->url(guard_url('ytrrr/ordetr/' . $ordetr->getRouteKey()))
                ->redirect();
        }

    }

    /**
     * Remove multiple ordetr.
     *
     * @param Model   $ordetr
     *
     * @return Response
     */
    public function delete(OrdetrRequest $request, $type)
    {
        try {
            $ids = hashids_decode($request->input('ids'));

            if ($type == 'purge') {
                $this->repository->purge($ids);
            } else {
                $this->repository->delete($ids);
            }

            return $this->response->message(trans('messages.success.deleted', ['Module' => trans('ytrrr::ordetr.name')]))
                ->status("success")
                ->code(202)
                ->url(guard_url('ytrrr/ordetr'))
                ->redirect();

        } catch (Exception $e) {

            return $this->response->message($e->getMessage())
                ->status("error")
                ->code(400)
                ->url(guard_url('/ytrrr/ordetr'))
                ->redirect();
        }

    }

    /**
     * Restore deleted ordetrs.
     *
     * @param Model   $ordetr
     *
     * @return Response
     */
    public function restore(OrdetrRequest $request)
    {
        try {
            $ids = hashids_decode($request->input('ids'));
            $this->repository->restore($ids);

            return $this->response->message(trans('messages.success.restore', ['Module' => trans('ytrrr::ordetr.name')]))
                ->status("success")
                ->code(202)
                ->url(guard_url('/ytrrr/ordetr'))
                ->redirect();

        } catch (Exception $e) {

            return $this->response->message($e->getMessage())
                ->status("error")
                ->code(400)
                ->url(guard_url('/ytrrr/ordetr/'))
                ->redirect();
        }

    }

}
